@@ -1,12 +1,8 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
-from abilian.core.entities import SEARCHABLE, Entity
 from sqlalchemy import Column, DateTime, Unicode
 from sqlalchemy.event import listens_for
 from sqlalchemy.orm import backref, relationship
 
+from abilian.core.entities import SEARCHABLE, Entity
 from abilian.sbe.apps.communities.models import Community, CommunityIdColumn, \
     community_content
 
