@@ -1,14 +1,12 @@
-# coding=utf-8
 """Forum views."""
-from __future__ import absolute_import, print_function, unicode_literals
-
 from datetime import date, datetime
 
+from flask import g, render_template
+from toolz import groupby
+
 from abilian.i18n import _l
 from abilian.web import url_for, views
 from abilian.web.action import ButtonAction
-from flask import g, render_template
-from toolz import groupby
 
 from ..communities.blueprint import Blueprint
 from ..communities.views import default_view_kw
@@ -53,7 +51,7 @@ def archives():
     return render_template("calendar/archives.html", **ctx)
 
 
-class BaseEventView(object):
+class BaseEventView:
     Model = Event
     Form = EventForm
     pk = "event_id"
@@ -73,7 +71,7 @@ class EventView(BaseEventView, views.ObjectView):
 
     @property
     def template_kwargs(self):
-        kw = super(EventView, self).template_kwargs
+        kw = super().template_kwargs
         kw["event"] = self.obj
         return kw
 
