@@ -1,20 +1,13 @@
-# coding=utf-8
 """Communities module."""
-from __future__ import absolute_import
-
-from abilian.sbe.extension import sbe
+from flask import Flask
 
 
-def register_plugin(app):
-    sbe.init_app(app)
-
+def register_plugin(app: Flask) -> None:
     # Used for side-effect
     from . import events  # noqa
-
+    from . import search
     from .views import communities
 
     app.register_blueprint(communities)
 
-    from . import search
-
     search.init_app(app)
