@@ -1,21 +1,18 @@
-# coding=utf-8
-# Note: this test suite is using pytest instead of the unittest-based scaffolding
-# provided by SBE. Hopefully one day all of SBE will follow.
-from __future__ import absolute_import, print_function, unicode_literals
-
 from tempfile import NamedTemporaryFile
+from typing import IO
 
 import pytest
-from abilian.core.models.subjects import User
 from flask import g
 
+from abilian.core.models.subjects import User
+from abilian.core.sqlalchemy import SQLAlchemy
 from abilian.sbe.apps.communities.models import READER, Community
 from abilian.sbe.apps.communities.views.wizard import wizard_extract_data, \
     wizard_read_csv
 
 
 @pytest.fixture
-def csv_file():
+def csv_file() -> IO[str]:
     # create a tmp csv file
     csv = NamedTemporaryFile("w+", suffix=".csv", prefix="tmp_", delete=False)
     csv.write("user_1@example.com;userone;userone;manager\n")
@@ -27,12 +24,11 @@ def csv_file():
     csv.write("example.com;example;userfour;member\n")
 
     csv.seek(0)
-    csv.filename = csv.name
 
     return csv
 
 
-def test_wizard_read_csv(csv_file):
+def test_wizard_read_csv(csv_file: IO[str]) -> None:
     wizard_read = wizard_read_csv(csv_file)
 
     assert wizard_read == [
@@ -57,7 +53,7 @@ def test_wizard_read_csv(csv_file):
     ]
 
 
-def test_wizard_extract_data(db, csv_file):
+def test_wizard_extract_data(db: SQLAlchemy, csv_file: IO[str]) -> None:
     session = db.session
     community = Community(name="Hp")
     g.community = community
@@ -88,9 +84,11 @@ def test_wizard_extract_data(db, csv_file):
     session.flush()
 
     # check wizard function in case of email list
-    existing_accounts_objects, existing_members_objects, accounts_list = wizard_extract_data(
-        new_emails
-    )
+    (
+        existing_accounts_objects,
+        existing_members_objects,
+        accounts_list,
+    ) = wizard_extract_data(new_emails)
     assert set(existing_accounts_objects) == {user2, user3}
     assert existing_members_objects == [user1]
 
@@ -132,9 +130,11 @@ def test_wizard_extract_data(db, csv_file):
     )
 
     # check wizard function in case of csv file
-    existing_accounts_objects, existing_members_objects, accounts_list = wizard_extract_data(
-        wizard_read_csv(csv_file), is_csv=True
-    )
+    (
+        existing_accounts_objects,
+        existing_members_objects,
+        accounts_list,
+    ) = wizard_extract_data(csv_data=wizard_read_csv(csv_file))
 
     assert existing_accounts_objects == {
         "csv_roles": {
