@@ -1,11 +1,10 @@
-# coding=utf-8
-from __future__ import absolute_import, print_function, unicode_literals
+from typing import Callable
 
-from abilian.core.extensions import db
 from flask import Blueprint, Response, make_response, render_template, request
 from sqlalchemy.orm.exc import NoResultFound
 from werkzeug.exceptions import NotFound, Unauthorized
 
+from abilian.core.extensions import db
 from abilian.sbe.apps.documents.repository import repository
 
 from .parser import Entry
@@ -15,6 +14,7 @@ from .renderer import Feed, to_xml
 # Constants
 #
 
+
 ROOT = "http://localhost:5000/cmis/atompub"
 
 # MIME TYPES (cf. section 3.3 of the CMIS specs)
@@ -34,7 +34,7 @@ route = atompub.route
 #
 # Dummy for now
 #
-class Logger(object):
+class Logger:
     def debug(self, msg):
         print(msg)
 
@@ -49,7 +49,7 @@ def log_result(result):
     print(78 * "-")
 
 
-def produces(*mimetypes):
+def produces(*mimetypes) -> Callable:
     def decorator(f):
         return f
 
@@ -101,7 +101,7 @@ def get_options(args):
         elif v in ("false", ""):
             v = False
         else:
-            raise Exception("Unexpected parameter value for %s: %s" % (k, v))
+            raise Exception(f"Unexpected parameter value for {k}: {v}")
         d[k] = v
     return d
 
@@ -201,11 +201,11 @@ def getObject():
     id = request.args.get("id")
     path = request.args.get("path")
 
-    log.debug("getObject called on id=%s, path=%s" % (id, path))
+    log.debug(f"getObject called on id={id}, path={path}")
     log.debug("URL: " + request.url)
 
     options = get_options(request.args)
-    log.debug("Options: %s" % options)
+    log.debug(f"Options: {options}")
 
     if id:
         obj = repository.get_object_by_id(id)
@@ -227,7 +227,7 @@ def updateProperties():
         path = request.args.get("path")
     else:
         path = ""
-    log.debug("updateProperties called on id=%s, path=%s" % (id, path))
+    log.debug(f"updateProperties called on id={id}, path={path}")
     log.debug("URL: " + request.url)
 
     obj = get_object(id)
@@ -241,7 +241,7 @@ def deleteObject():
         path = request.args.get("path")
     else:
         path = ""
-    log.debug("deleteObject called on id=%s, path=%s" % (id, path))
+    log.debug(f"deleteObject called on id={id}, path={path}")
     log.debug("URL: " + request.url)
 
     obj = get_object(id)
@@ -395,7 +395,7 @@ def createObject():
         db.session.commit()
 
     else:
-        raise Exception("Unknown object type: %s" % type)
+        raise Exception(f"Unknown object type: {type}")
 
     result = to_xml(new_object)
     log_result(result)
