@@ -1,23 +1,17 @@
-# coding=utf-8
-
-from __future__ import absolute_import, print_function, unicode_literals
-
-from abilian.web.forms import Form
-from abilian.web.forms import widgets as abilian_widgets
-from abilian.web.forms.fields import QuerySelect2Field
-from abilian.web.forms.filters import strip
-from abilian.web.forms.validators import optional, required
 from flask_babel import lazy_gettext as _l
 from wtforms import StringField, TextAreaField
 from wtforms_alchemy import model_form_factory
 
 from abilian.sbe.apps.communities.models import Community
+from abilian.web.forms import Form
+from abilian.web.forms import widgets as abilian_widgets
+from abilian.web.forms.fields import QuerySelect2Field
+from abilian.web.forms.filters import strip
+from abilian.web.forms.validators import optional, required
 
-ModelForm = model_form_factory(Form)
+ModelForm = model_form_factory(Form)  # type: Form
 
 
-# FIXME
-# type: ignore
 class UserProfileForm(ModelForm):
     pass
 
