@@ -1,17 +1,16 @@
-# coding=utf-8
 """Social content items: messages aka status updates, private messages, etc."""
-from __future__ import absolute_import, print_function, unicode_literals
-
 import re
+from typing import List
 
-from abilian.core.entities import SEARCHABLE, Entity
-from abilian.core.extensions import db
-from abilian.core.models.subjects import Group, User
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm.query import Query
 from sqlalchemy.schema import Column, ForeignKey
 from sqlalchemy.types import Integer, UnicodeText
 
+from abilian.core.entities import SEARCHABLE, Entity
+from abilian.core.extensions import db
+from abilian.core.models.subjects import Group, User
+
 __all__ = ["Message", "PrivateMessage"]
 
 
@@ -49,8 +48,8 @@ class Message(Entity):
     query = db.session.query_property(MessageQuery)
 
     @property
-    def tags(self):
-        return re.findall("#([^\W]+)(?u)", self.content)
+    def tags(self) -> List[str]:
+        return re.findall(r"(?u)#([^\W]+)", self.content)
 
 
 # TODO: inheriting from Entity is overkill here
