@@ -1,9 +1,12 @@
-# coding=utf-8
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from pathlib import Path
 
+from flask import current_app, flash, jsonify, make_response, redirect, \
+    render_template, request, url_for
+from flask_babel import gettext as _
+from flask_login import current_user
+from sqlalchemy import func
+from werkzeug.exceptions import InternalServerError, NotFound
+
 from abilian.core.extensions import db
 from abilian.core.models.subjects import Group, User
 from abilian.services import get_service
@@ -11,11 +14,6 @@ from abilian.services.image import CROP, resize
 from abilian.services.security import security
 from abilian.web import csrf
 from abilian.web.views import default_view
-from flask import current_app, flash, g, jsonify, make_response, redirect, \
-    render_template, request, url_for
-from flask_babel import gettext as _
-from sqlalchemy import func
-from werkzeug.exceptions import InternalServerError, NotFound
 
 from .social import social
 
@@ -27,16 +25,18 @@ DEFAULT_GROUP_MUGSHOT = (
 
 
 @social.route("/groups/")
-def groups():
+def groups() -> str:
     tab = request.args.get("tab", "all_groups")
     if tab == "all_groups":
         groups = Group.query.order_by(Group.name).all()
-        if not security.has_role(g.user, "admin"):
+        if not security.has_role(current_user, "admin"):
             groups = [
-                group for group in groups if group.public or g.user in group.members
+                group
+                for group in groups
+                if group.public or current_user in group.members
             ]
     else:
-        groups = g.user.groups
+        groups = current_user.groups
         groups.sort(key=lambda x: x.name)
 
     return render_template("social/groups.html", groups=groups)
@@ -44,9 +44,9 @@ def groups():
 
 def is_admin(group):
     security = get_service("security")
-    is_admin = g.user in group.admins
+    is_admin = current_user in group.admins
     if not is_admin and "security" in current_app.extensions:
-        is_admin = security.has_role(g.user, "admin")
+        is_admin = security.has_role(current_user, "admin")
 
     return is_admin
 
@@ -89,15 +89,15 @@ def group_post(group_id):
     membership_actions = frozenset(("add", "remove", "add-admin", "remove-admin"))
 
     if action not in {"join", "leave"}.union(membership_actions):
-        raise ValueError("Unknown action: {}".format(action))
+        raise ValueError(f"Unknown action: {action}")
 
     if action not in ("join", "leave"):
         assert is_admin(group)
 
     if action == "join":
-        g.user.join(group)
+        current_user.join(group)
     elif action == "leave":
-        g.user.leave(group)
+        current_user.leave(group)
 
     elif action in membership_actions:
         try:
@@ -164,7 +164,7 @@ def group_mugshot(group_id):
     # TODO: duplicated code (with user_mugshot). Extract common method.
     size = int(request.args.get("s", 55))
     if size > 500:
-        raise ValueError("Error, size = %d" % size)
+        raise ValueError(f"Error, size = {size:d}")
     group = Group.query.get(group_id)
 
     if not group:
