@@ -1,26 +1,24 @@
-# coding=utf-8
 """Provides content for sidebars, accessible via the 'g' object.
 
 TODO: make it smarter (direct access from 'g' using lazy objects?) and
 cacheable.
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 from datetime import datetime, timedelta
+from typing import List
 
-from abilian.core.models.subjects import User
 from flask import g
 from flask_login import current_user
 
+from abilian.core.models.subjects import User
 from abilian.sbe.apps.communities.models import Community, Membership
 
 from .social import social
 
 
-class Sidebars(object):
+class Sidebars:
     @property
-    def latest_visitors(self):
+    def latest_visitors(self) -> List[User]:
         return (
             User.query.filter(User.last_active != None)
             .order_by(User.last_active.desc())
@@ -34,7 +32,7 @@ class Sidebars(object):
         return User.query.filter(User.last_active > one_minute_ago).count()
 
     @property
-    def my_communities(self):
+    def my_communities(self) -> List[Community]:
         query = Community.query
         query = query.order_by(Community.last_active_at.desc())
         if not current_user.has_role("admin"):
@@ -50,5 +48,5 @@ class Sidebars(object):
 
 
 @social.before_request
-def inject_sidebars():
+def inject_sidebars() -> None:
     g.sidebars = Sidebars()
