@@ -1,17 +1,13 @@
-# coding=utf-8
 """The blueprint for this app."""
 
-from __future__ import absolute_import, print_function, unicode_literals
+from flask import Blueprint, redirect, render_template, url_for
 
 from abilian.core.extensions import db
 from abilian.core.util import get_params
-from flask import Blueprint, redirect, render_template, url_for
-
+from abilian.sbe.apps.social.models import Message
 from abilian.sbe.apps.wall.presenters import ActivityEntryPresenter
 from abilian.sbe.apps.wall.util import get_recent_entries
 
-from ..models import Message
-
 __all__ = ["social"]
 
 MAX_LAST_USERS = 15
@@ -24,7 +20,7 @@ route = social.route
 
 
 @route("/")
-def home():
+def home() -> str:
     ctx = {}
     entries = get_recent_entries(num=50)
     entries = ActivityEntryPresenter.wrap_collection(entries)
